@@ -7,20 +7,13 @@ import os
 import pandas as pd
 import synapseclient
 
-try:
-    from synapseclient.core.retry import with_retry
-except ModuleNotFoundError:
-    # For synapseclient < v2.0
-    from synapseclient.retry import _with_retry as with_retry
+from synapseclient.core.retry import with_retry
+from synapseclient.core.utils import from_unix_epoch_time
 
-from . import createchallenge
-from . import download_current_lead_submission as dl_cur
-from . import evaluation_queue
-from . import helpers
-from . import mirrorwiki
-from . import permissions
-from . import utils
-from . import writeup_attacher
+from . import (createchallenge, challenge,
+               download_current_lead_submission as dl_cur,
+               evaluation_queue, helpers, mirrorwiki, permissions, utils,
+               writeup_attacher)
 from .__version__ import __version__
 
 logging.basicConfig(level=logging.INFO)
@@ -28,17 +21,20 @@ logger = logging.getLogger(__name__)
 
 
 def command_mirrorwiki(syn, args):
-    """For all challenges, you should be editting the staging site and then
-    using the merge script to mirror staging to live site.  The script will
-    compare wiki titles between the staging and live site and update the live
-    site with respect to what has changed on the staging site.  Note, this is
-    different from copying the wikis. To copy the wikis, please look at
-    synapseutils.
+    """Mirrors (sync) wiki pages by using the wikipage titles between two
+    Synapse Entities.  This function only works if `entity` and `destination`
+    are the same type and both must have wiki pages.  Only wiki pages with the
+    same titles will be copied from `entity` to `destination` - if there is
+    a wiki page that you want to add, you will have to create a wiki page
+    first in the `destination` with the same name.
+
+    Note: this is different from copying a wiki - to copy a wiki, please look
+    at `synapseutils.copyWiki`.
 
     >>> challengeutils mirrorwiki syn12345 syn23456
     """
-    mirrorwiki.mirrorwiki(syn, args.entityid, args.destinationid,
-                          args.forceupdate)
+    mirrorwiki.mirror(syn, args.entityid, args.destinationid,
+                      force=args.force, dryrun=args.dryrun)
 
 
 def command_createchallenge(syn, args):
@@ -88,7 +84,7 @@ def command_query(syn, args):
             querydf['submitterName'] = submitter_names
         # Check if createdOn column exists
         if querydf.get('createdOn') is not None:
-            createdons = [synapseclient.utils.from_unix_epoch_time(createdon)
+            createdons = [from_unix_epoch_time(createdon)
                           for createdon in querydf['createdOn']]
             querydf['createdOn'] = createdons
     if args.outputfile is not None:
@@ -184,6 +180,10 @@ def command_list_evaluations(syn, args):
 
 
 def command_download_submission(syn, args):
+    """Downloads a Synapse Submission given a submission id
+
+    >>> challengeutils downloadsubmission submissionid
+    """
     submission_dict = utils.download_submission(syn, args.submissionid,
                                                 download_location=args.download_location) # noqa pylint: disable=line-too-long
     if args.output:
@@ -240,6 +240,17 @@ def command_kill_docker_over_quota(syn, args):
                                               quota=args.quota)
 
 
+def command_list_registered_challenges(syn, args):
+    """
+    List the challenges a user is registered to. Defaults to the
+    logged in synapse user is userid isn't specified.
+
+    >>> challengeutils list-registered-challenges
+    >>> challengeutils list-registered-challenges --userid 1223
+    """
+    list(challenge.get_registered_challenges(syn, userid=args.userid))
+
+
 def build_parser():
     """Builds the argument parser and returns the result."""
     parser = argparse.ArgumentParser(
@@ -270,27 +281,39 @@ def build_parser():
               " there is already a live site"))
     parser_createChallenge.set_defaults(func=command_createchallenge)
 
-    parser_mirrorWiki = subparsers.add_parser(
+    parser_mirrorwiki = subparsers.add_parser(
         'mirrorwiki',
-        help=("This command mirrors wiki pages. It relies on the wiki titles "
-              "between two Synapse Projects to be the same and will merge the "
-              "updates from entity's wikis to destination's wikis. "
-              "Do not confuse this function with copy wiki."))
+        help="Mirrors (sync) wiki pages by using the wikipage titles between "
+             "two Synapse Entities. This function only works if `entity` and "
+             "`destination`are the same type and both must have wiki pages. "
+             "Only wiki pages with the same titles will be copied from "
+             "`entity` to `destination` - if there is a wiki page that you "
+             "want to add, you will have to create a wiki page first in the "
+             "`destination` with the same name."
+    )
 
-    parser_mirrorWiki.add_argument(
+    parser_mirrorwiki.add_argument(
         "entityid",
         type=str,
-        help="Synapse Id of the project's wiki changes you have staged")
-    parser_mirrorWiki.add_argument(
+        help="Synapse Id of the project's wiki changes you have staged"
+    )
+    parser_mirrorwiki.add_argument(
         "destinationid",
         type=str,
-        help=('Synapse Id of project whose wiki you want to update'
-              ' with the entityid'))
-    parser_mirrorWiki.add_argument(
-        "--forceupdate",
+        help="Synapse Id of project whose wiki you want to update "
+             "with the entityid"
+    )
+    parser_mirrorwiki.add_argument(
+        "-f", "--force",
         action='store_true',
-        help='Update the wikipages even if they are the same')
-    parser_mirrorWiki.set_defaults(func=command_mirrorwiki)
+        help='Update the wikipages even if they are the same'
+    )
+    parser_mirrorwiki.add_argument(
+        "--dryrun",
+        action='store_true',
+        help="Show the pages that have changed but don't update."
+    )
+    parser_mirrorwiki.set_defaults(func=command_mirrorwiki)
 
     parser_query = subparsers.add_parser(
         'query',
@@ -554,6 +577,22 @@ def build_parser():
 
     parser_set_quota.set_defaults(func=command_set_evaluation_quota)
 
+    parser_list_challenge = subparsers.add_parser(
+        'list-registered-challenges',
+        help="List the challenges a user is registered to. Defaults to the"
+             "logged in synapse user is userid isn't specified."
+    )
+
+    parser_list_challenge.add_argument(
+        "--userid",
+        type=str,
+        help='Synapse User id or username',
+        default=None
+    )
+
+    parser_list_challenge.set_defaults(
+        func=command_list_registered_challenges
+    )
     return parser
 
 
